@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * boot.c: the external interface to the MS Excel import/export
@@ -24,11 +23,11 @@
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 
-#include "libgnumeric.h"
-#include "command-context.h"
-#include "workbook-view.h"
-#include "workbook.h"
-#include "gnm-plugin.h"
+#include <libgnumeric.h>
+#include <command-context.h>
+#include <workbook-view.h>
+#include <workbook.h>
+#include <gnm-plugin.h>
 
 #include "excel.h"
 #include "ms-excel-write.h"
