@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Range lookup functions
  *
@@ -1966,70 +1965,70 @@ gnumeric_sort (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 GnmFuncDescriptor const lookup_functions[] = {
 	{ "address",   "ff|fbs",
-	  help_address,  gnumeric_address, NULL, NULL, NULL,
+	  help_address,  gnumeric_address, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "areas", NULL,
-	  help_areas,	NULL,	gnumeric_areas, NULL, NULL,
+	  help_areas,	NULL,	gnumeric_areas,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "choose", NULL,
-	  help_choose,	NULL,	gnumeric_choose, NULL, NULL,
+	  help_choose,	NULL,	gnumeric_choose,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "column",     "|A",
-	  help_column,   gnumeric_column, NULL, NULL, NULL,
+	  help_column,   gnumeric_column, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "columnnumber", "s",
-	  help_columnnumber, gnumeric_columnnumber, NULL, NULL, NULL,
+	  help_columnnumber, gnumeric_columnnumber, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "columns",   "A",
-	  help_columns, gnumeric_columns, NULL, NULL, NULL,
+	  help_columns, gnumeric_columns, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "hlookup",   "EAf|bb",
-	  help_hlookup, gnumeric_hlookup, NULL, NULL, NULL,
+	  help_hlookup, gnumeric_hlookup, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "hyperlink", "S|S",
-	  help_hyperlink, gnumeric_hyperlink, NULL, NULL, NULL,
+	  help_hyperlink, gnumeric_hyperlink, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_SUBSET, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "indirect",  "s|b",
-	  help_indirect, gnumeric_indirect, NULL, NULL, NULL,
+	  help_indirect, gnumeric_indirect, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "index",     "A|fff",
-	  help_index,    NULL, gnumeric_index, NULL, NULL,
+	  help_index,    NULL, gnumeric_index,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "lookup",    "EA|r",
-	  help_lookup,   gnumeric_lookup, NULL, NULL, NULL,
+	  help_lookup,   gnumeric_lookup, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "match",     "EA|f",
-	  help_match,    gnumeric_match, NULL, NULL, NULL,
+	  help_match,    gnumeric_match, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "offset",    "rff|ff",
-	  help_offset,   gnumeric_offset, NULL, NULL, NULL,
+	  help_offset,   gnumeric_offset, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "row",       "|A",
-	  help_row,      gnumeric_row, NULL, NULL, NULL,
+	  help_row,      gnumeric_row, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "rows",      "A",
-	  help_rows,     gnumeric_rows, NULL, NULL, NULL,
+	  help_rows,     gnumeric_rows, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "sheets",      "|A",
-	  help_sheets,     gnumeric_sheets, NULL, NULL, NULL,
+	  help_sheets,     gnumeric_sheets, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "sheet",      "|?",
-	  help_sheet,     gnumeric_sheet, NULL, NULL, NULL,
+	  help_sheet,     gnumeric_sheet, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "sort",         "r|f",
-	  help_sort, gnumeric_sort, NULL, NULL, NULL,
+	  help_sort, gnumeric_sort, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "transpose", "A",
-	  help_transpose, gnumeric_transpose, NULL, NULL, NULL,
+	  help_transpose, gnumeric_transpose, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "vlookup",   "EAf|bb",
-	  help_vlookup, gnumeric_vlookup, NULL, NULL, NULL,
+	  help_vlookup, gnumeric_vlookup, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "array", NULL,
-	  help_array, NULL, gnumeric_array, NULL, NULL,
+	  help_array, NULL, gnumeric_array,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "flip", "A|b",
-	  help_flip, gnumeric_flip, NULL, NULL, NULL,
+	  help_flip, gnumeric_flip, NULL,
 	  GNM_FUNC_RETURNS_NON_SCALAR, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         {NULL}
