@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * sylk-write.c : export sylk
  *
@@ -22,18 +21,18 @@
 
 #include <gnumeric-config.h>
 
-#include "workbook-priv.h"
-#include "workbook-view.h"
-#include "sheet.h"
-#include "sheet-style.h"
-#include "expr.h"
-#include "value.h"
-#include "cell.h"
-#include "mstyle.h"
-#include "gutils.h"
-#include "parse-util.h"
-#include "style-border.h"
-#include "ranges.h"
+#include <workbook-priv.h>
+#include <workbook-view.h>
+#include <sheet.h>
+#include <sheet-style.h>
+#include <expr.h>
+#include <value.h>
+#include <cell.h>
+#include <mstyle.h>
+#include <gutils.h>
+#include <parse-util.h>
+#include <style-border.h>
+#include <ranges.h>
 
 #include <goffice/goffice.h>
 
