@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-analysis-tool-chi-squared.c:
  *
@@ -18,16 +17,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "analysis-chi-squared.h"
-#include "analysis-tools.h"
+#include <dialogs/dialogs.h>
+#include <tools/analysis-chi-squared.h>
+#include <tools/analysis-tools.h>
 
 #include <workbook.h>
 #include <workbook-control.h>
@@ -36,8 +34,8 @@
 #include <gui-util.h>
 #include <parse-util.h>
 #include <gnm-format.h>
-#include <tool-dialogs.h>
-#include <dao-gui-utils.h>
+#include <dialogs/tool-dialogs.h>
+#include <dialogs/dao-gui-utils.h>
 #include <sheet.h>
 #include <expr.h>
 #include <number-match.h>
@@ -45,18 +43,17 @@
 #include <selection.h>
 #include <value.h>
 #include <commands.h>
-#include "help.h"
+#include <dialogs/help.h>
 
 #include <widgets/gnm-dao.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 
 #include <string.h>
-#include <gtk/gtk.h>
 
 #define CHI_SQUARED_I_KEY      "analysistools-chi-square-independence-dialog"
 
 typedef struct {
-	GenericToolState base;
+	GnmGenericToolState base;
 	GtkWidget *alpha_entry;
 	GtkWidget *label;
 } ChiSquaredIToolState;
@@ -79,13 +76,13 @@ chi_squared_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	analysis_tools_data_chi_squared_t *data;
 
 	data = g_new0 (analysis_tools_data_chi_squared_t, 1);
-	dao  = parse_output ((GenericToolState *)state, NULL);
+	dao  = parse_output ((GnmGenericToolState *)state, NULL);
 
 	data->input = gnm_expr_entry_parse_as_value
 		(GNM_EXPR_ENTRY (state->base.input_entry),
 		 state->base.sheet);
 
-	data->wbc = WORKBOOK_CONTROL (state->base.wbcg);
+	data->wbc = GNM_WBC (state->base.wbcg);
 
         data->labels = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (state->label));
 
@@ -207,14 +204,14 @@ dialog_chi_square_tool (WBCGtk *wbcg, Sheet *sheet, gboolean independence)
 		return 1;
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, CHI_SQUARED_I_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, CHI_SQUARED_I_KEY))
 		return 0;
 
 	state = g_new0 (ChiSquaredIToolState, 1);
 
 	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_CHI_SQUARED,
-			      "chi-squared.ui", "Chi-Squared Tests",
+			      "res:ui/chi-squared.ui", "Chi-Squared Tests",
 			      _("Could not create the Chi Squared Tests "
 				"tool dialog."),
 			      CHI_SQUARED_I_KEY,
@@ -249,7 +246,7 @@ dialog_chi_square_tool (WBCGtk *wbcg, Sheet *sheet, gboolean independence)
 
 	gnm_dao_set_put (GNM_DAO (state->base.gdao), TRUE, TRUE);
 	chi_squared_tool_update_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 
         return 0;
 }
