@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-analysis-tool-one-mean.c:
  *
@@ -18,16 +17,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "analysis-one-mean-test.h"
-#include "analysis-tools.h"
+#include <dialogs/dialogs.h>
+#include <tools/analysis-one-mean-test.h>
+#include <tools/analysis-tools.h>
 
 #include <workbook.h>
 #include <workbook-control.h>
@@ -36,8 +34,8 @@
 #include <gui-util.h>
 #include <parse-util.h>
 #include <gnm-format.h>
-#include <tool-dialogs.h>
-#include <dao-gui-utils.h>
+#include <dialogs/tool-dialogs.h>
+#include <dialogs/dao-gui-utils.h>
 #include <sheet.h>
 #include <expr.h>
 #include <number-match.h>
@@ -45,13 +43,12 @@
 #include <selection.h>
 #include <value.h>
 #include <commands.h>
-#include "help.h"
+#include <dialogs/help.h>
 
 #include <widgets/gnm-dao.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 
 #include <string.h>
-#include <gtk/gtk.h>
 
 #define ONE_MEAN_TEST_KEY      "analysistools-one-mean-test-dialog"
 
@@ -63,7 +60,7 @@ static char const * const grouped_by_group[] = {
 };
 
 typedef struct {
-	GenericToolState base;
+	GnmGenericToolState base;
 	GtkWidget *alpha_entry;
 	GtkWidget *mean_entry;
 } OneeMeanTestToolState;
@@ -138,7 +135,7 @@ one_mean_test_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	analysis_tools_data_one_mean_test_t *data;
 
 	data = g_new0 (analysis_tools_data_one_mean_test_t, 1);
-	dao  = parse_output ((GenericToolState *)state, NULL);
+	dao  = parse_output ((GnmGenericToolState *)state, NULL);
 
 	data->base.input = gnm_expr_entry_parse_as_list (
 		GNM_EXPR_ENTRY (state->base.input_entry), state->base.sheet);
@@ -153,7 +150,7 @@ one_mean_test_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	data->alpha = gtk_spin_button_get_value
 		(GTK_SPIN_BUTTON (state->alpha_entry));
 
-	if (!cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg),
+	if (!cmd_analysis_tool (GNM_WBC (state->base.wbcg),
 				state->base.sheet,
 				dao, data, analysis_tool_one_mean_test_engine,
 				TRUE))
@@ -214,14 +211,14 @@ dialog_one_mean_test_tool (WBCGtk *wbcg, Sheet *sheet)
 		return 1;
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, ONE_MEAN_TEST_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, ONE_MEAN_TEST_KEY))
 		return 0;
 
 	state = g_new0 (OneeMeanTestToolState, 1);
 
 	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_ONE_MEAN,
-			      "one-mean-test.ui", "One-Mean-Test",
+			      "res:ui/one-mean-test.ui", "One-Mean-Test",
 			      _("Could not create the Student-t Test Tool dialog."),
 			      ONE_MEAN_TEST_KEY,
 			      G_CALLBACK (one_mean_test_tool_ok_clicked_cb),
@@ -248,7 +245,7 @@ dialog_one_mean_test_tool (WBCGtk *wbcg, Sheet *sheet)
 
 	gnm_dao_set_put (GNM_DAO (state->base.gdao), TRUE, TRUE);
 	one_mean_test_tool_update_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 
 	return 0;
 
