@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-autoformat.c : implementation of the autoformat dialog
  *
@@ -26,8 +25,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
 #include <mstyle.h>
@@ -45,7 +44,6 @@
 #include <ranges.h>
 
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
@@ -202,7 +200,7 @@ templates_free (AutoFormatState *state)
  * This function will load the templates in the currently selected
  * category group (it looks at state->category_groups to determine the selection)
  *
- * Return value: TRUE if all went well, FALSE otherwise.
+ * Returns: %TRUE if all went well, %FALSE otherwise.
  **/
 static gboolean
 templates_load (AutoFormatState *state)
@@ -283,7 +281,7 @@ previews_free (AutoFormatState *state)
  *
  * This function will create grids and rects for each canvas and associate
  * them with the right format templates.
- * NOTE : if state->preview_locked is TRUE this function will do nothing,
+ * NOTE : if state->preview_locked is %TRUE this function will do nothing,
  *        this is handy in situation where signals can cause previews_load to be
  *        called before previews_free.
  **/
@@ -390,7 +388,7 @@ cb_canvas_button_press (GocCanvas *canvas,
 	GSList *ptr;
 	int index = 0;
 
-	while (canvas != state->canvas[index] && index < NUM_PREVIEWS)
+	while (index < NUM_PREVIEWS && canvas != state->canvas[index])
 		index++;
 
 	g_return_val_if_fail (index < NUM_PREVIEWS, FALSE);
@@ -499,7 +497,7 @@ cb_canvas_focus (GtkWidget *canvas,
 
 /**
  * dialog_autoformat:
- * @wb: The Workbook
+ * @wbcg: the control that invoked this dialog
  *
  * This function will show the AutoFormatTemplate dialog and apply
  * the template the user chooses to the current selection in the active
@@ -512,7 +510,7 @@ dialog_autoformat (WBCGtk *wbcg)
 	AutoFormatState *state;
 	int i;
 
-	gui = gnm_gtk_builder_load ("autoformat.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/autoformat.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
