@@ -24,8 +24,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <workbook-view.h>
 #include <gui-util.h>
@@ -41,11 +41,10 @@
 #include <sheet-view.h>
 #include <wbc-gtk.h>
 #include <gnumeric-conf.h>
-#include <widgets/gnumeric-cell-renderer-toggle.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-cell-renderer-toggle.h>
+#include <widgets/gnm-expr-entry.h>
 #include <value.h>
 
-#include <gtk/gtk.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gdk/gdkkeysyms.h>
 #include <goffice/goffice.h>
@@ -609,8 +608,9 @@ dialog_load_selection (SortFlowState *state, gboolean *col_rb)
 }
 
 /**
- * Refreshes the buttons on a row (un)selection
+ * cb_sort_selection_changed:
  *
+ * Refreshes the buttons on a row (un)selection
  */
 static void
 cb_sort_selection_changed (SortFlowState *state)
@@ -1015,7 +1015,7 @@ dialog_init (SortFlowState *state)
 		 "text", ITEM_NAME, NULL);
 	gtk_tree_view_append_column (state->treeview, column);
 
-	renderer = gnumeric_cell_renderer_toggle_new ();
+	renderer = gnm_cell_renderer_toggle_new ();
 	g_signal_connect (G_OBJECT (renderer),
 			  "toggled",
 			  G_CALLBACK (cb_toggled_descending), state);
@@ -1153,7 +1153,7 @@ dialog_cell_sort (WBCGtk *wbcg)
 	if (gnm_dialog_raise_if_exists (wbcg, CELL_SORT_KEY))
 		return;
 
-	gui = gnm_gtk_builder_load ("cell-sort.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/cell-sort.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
             return;
 
