@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * dialog-data-table.c: Create a Data Table
@@ -22,8 +21,8 @@
  */
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <expr.h>
 #include <selection.h>
@@ -36,8 +35,7 @@
 #include <parse-util.h>
 #include <commands.h>
 #include <ranges.h>
-#include <widgets/gnumeric-expr-entry.h>
-#include <gtk/gtk.h>
+#include <widgets/gnm-expr-entry.h>
 #include <glib/gi18n.h>
 
 #define DIALOG_DATA_TABLE_KEY "dialog-data-table"
@@ -92,7 +90,7 @@ cb_data_table_response (GtkWidget *dialog, gint response_id, GnmDialogDataTable
 static gboolean
 data_table_init (GnmDialogDataTable *state, WBCGtk *wbcg)
 {
-	state->gui = gnm_gtk_builder_load ("data-table.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	state->gui = gnm_gtk_builder_load ("res:ui/data-table.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (state->gui == NULL)
                 return TRUE;
 
