@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-function-select.c:  Implements the function selector
  *
@@ -25,8 +24,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
 #include <gutils.h>
@@ -43,11 +42,8 @@
 #include <auto-format.h>
 
 #include <gsf/gsf-impl-utils.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
-#define F2(func,s) dgettext ((func)->tdomain->str, (s))
-
 #define FUNCTION_SELECT_KEY "function-selector-dialog"
 #define FUNCTION_SELECT_HELP_KEY "function-selector-dialog-help-mode"
 #define FUNCTION_SELECT_PASTE_KEY "function-selector-dialog-paste-mode"
@@ -311,7 +307,7 @@ cb_unref (GtkTreeModel *model, G_GNUC_UNUSED GtkTreePath *path,
 	gtk_tree_model_get (model, iter,
 			    FUNCTION, &f,
 			    -1);
-	gnm_func_unref (f);
+	gnm_func_dec_usage (f);
 	return FALSE;
 }
 
@@ -577,12 +573,11 @@ make_link (GtkTextBuffer *description, GtkWidget *target, const char *name,
 		(gtk_text_buffer_get_tag_table (description), name);
 
 	if (!link) {
-		GdkColor *link_color = NULL;
+		GdkRGBA link_color;
 		char *link_color_text;
 
-		gtk_widget_style_get (target, "link-color", &link_color, NULL);
-		link_color_text = gdk_color_to_string (link_color);
-		gdk_color_free (link_color);
+		gnm_get_link_color (target, &link_color);
+		link_color_text = gdk_rgba_to_string (&link_color);
 
 		link = gtk_text_buffer_create_tag
 			(description, name,
@@ -729,7 +724,7 @@ make_expr_example (Sheet *sheet, const char *text,
 static void
 describe_new_style (GtkTextBuffer *description,
 		    GtkWidget *target,
-		    GnmFunc const *func, Sheet *sheet)
+		    GnmFunc *func, Sheet *sheet)
 {
 	GnmFuncHelp const *help;
 	GtkTextIter ti;
@@ -744,13 +739,16 @@ describe_new_style (GtkTextBuffer *description,
 	gboolean seen_extref = FALSE;
 	gboolean is_TEXT =
 		g_ascii_strcasecmp (gnm_func_get_name (func, FALSE), "TEXT") == 0;
+	int n;
 
 	gtk_text_buffer_get_end_iter (description, &ti);
 
-	for (help = func->help; 1; help++) {
+	help = gnm_func_get_help (func, &n);
+
+	for (; n-- > 0; help++) {
 		switch (help->type) {
 		case GNM_FUNC_HELP_NAME: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			const char *colon = strchr (text, ':');
 			if (!colon)
 				break;
@@ -761,7 +759,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 		case GNM_FUNC_HELP_ARG: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			const char *colon = strchr (text, ':');
 			if (!colon)
 				break;
@@ -779,7 +777,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 		case GNM_FUNC_HELP_DESCRIPTION: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			FINISH_ARGS;
 			ADD_TEXT ("\n");
 			ADD_TEXT_WITH_ARGS (text);
@@ -787,7 +785,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 		case GNM_FUNC_HELP_NOTE: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			FINISH_ARGS;
 			ADD_TEXT ("\n");
 			ADD_TEXT (_("Note: "));
@@ -796,7 +794,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 		case GNM_FUNC_HELP_EXAMPLES: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			gboolean was_translated = (text != help->text);
 
 			FINISH_ARGS;
@@ -844,9 +842,6 @@ describe_new_style (GtkTextBuffer *description,
 			ADD_TEXT ("\n");
 			break;
 		}
-		case GNM_FUNC_HELP_END:
-			FINISH_ARGS;
-			return;
 		case GNM_FUNC_HELP_EXTREF: {
 			GtkTextTag *link;
 			char *uri, *tagname;
@@ -883,7 +878,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 		case GNM_FUNC_HELP_EXCEL: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			FINISH_ARGS;
 			ADD_TEXT ("\n");
 			ADD_TEXT (_("Microsoft Excel: "));
@@ -892,7 +887,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 		case GNM_FUNC_HELP_ODF: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			FINISH_ARGS;
 			ADD_TEXT ("\n");
 			ADD_TEXT (_("ODF (OpenFormula): "));
@@ -904,6 +899,7 @@ describe_new_style (GtkTextBuffer *description,
 			break;
 		}
 	}
+	FINISH_ARGS;
 }
 
 #undef ADD_TEXT_WITH_ARGS
@@ -1049,7 +1045,7 @@ cb_dialog_function_select_fun_selection_changed (GtkTreeSelection *selection,
 {
 	GtkTreeIter  iter;
 	GtkTreeModel *model;
-	GnmFunc const *func;
+	GnmFunc *func;
 	GtkTextBuffer *description;
 	GtkTextMark *mark;
 	gboolean active = FALSE;
@@ -1066,9 +1062,9 @@ cb_dialog_function_select_fun_selection_changed (GtkTreeSelection *selection,
 				    FUNCTION, &func,
 				    -1);
 
-		gnm_func_load_if_stub ((GnmFunc *)func);
+		gnm_func_load_if_stub (func);
 
-		if (func->help == NULL)
+		if (gnm_func_get_help (func, NULL) == NULL)
 			gtk_text_buffer_set_text (description, "?", -1);
 		else
 			describe_new_style (description,
@@ -1089,14 +1085,15 @@ static const gchar *
 dialog_function_select_peek_description (GnmFunc *func)
 {
 	GnmFuncHelp const *help;
+	int n;
 
 	gnm_func_load_if_stub (func);
-	help = func->help;
 
+	help = gnm_func_get_help (func, &n);
 	if (help == NULL)
 		return "";
 
-	for (; TRUE; help++) {
+	for (; n-- > 0; help++) {
 		switch (help->type) {
 		case GNM_FUNC_HELP_ARG:
 		case GNM_FUNC_HELP_NOTE:
@@ -1109,14 +1106,13 @@ dialog_function_select_peek_description (GnmFunc *func)
 		default:
 			break;
 		case GNM_FUNC_HELP_NAME: {
-			const char *text = F2 (func, help->text);
+			const char *text = gnm_func_gettext (func, help->text);
 			const char *colon = strchr (text, ':');
 			return (colon ? colon + 1 : text);
 		}
-		case GNM_FUNC_HELP_END:
-			return "";
 		}
 	}
+	return "";
 }
 
 
@@ -1182,10 +1178,11 @@ dialog_function_select_load_tree (FunctionSelectState *state)
 
 	for (ptr = funcs; ptr; ptr = ptr->next) {
 		func = ptr->data;
-		if (!(func->flags &
+		if (!(gnm_func_get_flags (func) &
 		      (GNM_FUNC_INTERNAL | GNM_FUNC_IS_PLACEHOLDER))) {
+			gboolean in_use = gnm_func_get_in_use (func);
 			gtk_list_store_append (state->model_functions, &iter);
-			gnm_func_ref (func);
+			gnm_func_inc_usage (func);
 			desc = dialog_function_select_get_description (func, &pal);
 			gtk_list_store_set
 				(state->model_functions, &iter,
@@ -1193,10 +1190,10 @@ dialog_function_select_load_tree (FunctionSelectState *state)
 				 FUNCTION, func,
 				 FUNCTION_DESC, desc,
 				 FUNCTION_PAL, pal,
-				 FUNCTION_CAT, func->fn_group,
+				 FUNCTION_CAT, gnm_func_get_function_group (func),
 				 FUNCTION_VISIBLE, TRUE,
 				 FUNCTION_RECENT, FALSE,
-				 FUNCTION_USED, (func->usage_count > 1),
+				 FUNCTION_USED, in_use,
 				 -1);
 			g_free (desc);
 			pango_attr_list_unref (pal);
@@ -1404,7 +1401,7 @@ dialog_function_select_full (WBCGtk *wbcg, char const *guru_key,
 
 	if (gnm_dialog_raise_if_exists (wbcg, key))
 		return;
-	gui = gnm_gtk_builder_load ("function-select.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/function-select.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
 		return;
 
