@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-preferences.c: Dialog to edit application wide preferences and default values
  *
@@ -19,29 +18,27 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "application.h"
-#include "dialogs.h"
-#include "help.h"
+#include <application.h>
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
-#include "mstyle.h"
-#include "value.h"
+#include <mstyle.h>
+#include <value.h>
 #include <gnm-format.h>
-#include "workbook.h"
-#include "workbook-control.h"
-#include "wbc-gtk.h"
-#include "number-match.h"
-#include "widgets/gnumeric-cell-renderer-text.h"
+#include <workbook.h>
+#include <workbook-control.h>
+#include <wbc-gtk.h>
+#include <number-match.h>
+#include <widgets/gnm-cell-renderer-text.h>
 
-#include "gnumeric-conf.h"
+#include <gnumeric-conf.h>
 
 #include <gui-util.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
@@ -1112,6 +1109,7 @@ pref_copypaste_page_initializer (PrefState *state,
 				 page, row++,
 				 gnm_conf_set_cut_and_paste_prefer_clipboard,
 				 gnm_conf_get_cut_and_paste_prefer_clipboard,
+				 /* xgettext : see https://en.wikipedia.org/wiki/X_Window_selection#Clipboard */
 				 _("Prefer CLIPBOARD Over PRIMARY Selection"));
 
 	gtk_widget_show_all (page);
@@ -1342,7 +1340,7 @@ dialog_preferences (WBCGtk *wbcg, gchar const *page)
 		return;
 	}
 
-	gui = gnm_gtk_builder_load ("preferences.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/preferences.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
