@@ -10,13 +10,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef GNUMERIC_DIALOG_STF_EXPORT_H
 #define GNUMERIC_DIALOG_STF_EXPORT_H
 
-#include "gnumeric-fwd.h"
+#include <gnumeric-fwd.h>
 
 gboolean stf_export_dialog (WBCGtk *wbcg, GnmStfExport *stfe, Workbook *wb);
 
