@@ -1,4 +1,4 @@
-/**
+/*
  * dialog-view.c:  New view dialog.
  *
  * Author:
@@ -22,13 +22,12 @@
 
 #include <gnumeric-config.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
-#include "application.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
+#include <application.h>
 #include <gui-util.h>
 #include <wbc-gtk.h>
 
-#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 
 #define VIEW_DIALOG_KEY "view-dialog"
@@ -106,7 +105,7 @@ cb_view_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 		/* What else would it be?  */
 		WBCGtk *new_wbcg = WBC_GTK (new_wbc);
 		wbcg_copy_toolbar_visibility (new_wbcg, wbcg);
-		_gnm_app_flag_windows_changed ();
+		gnm_app_flag_windows_changed_ ();
 	}
 }
 
@@ -130,7 +129,7 @@ dialog_new_view (WBCGtk *wbcg)
 
 	if (gnm_dialog_raise_if_exists (wbcg, VIEW_DIALOG_KEY))
 		return;
-	gui = gnm_gtk_builder_load ("view.ui", NULL, GO_CMD_CONTEXT (wbcg));
+	gui = gnm_gtk_builder_load ("res:ui/view.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
