@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,14 +15,13 @@
 #ifndef GNUMERIC_TOOL_DIALOGS_H
 #define GNUMERIC_TOOL_DIALOGS_H
 
-#include "gnumeric.h"
-#include "numbers.h"
-#include "widgets/gnumeric-expr-entry.h"
+#include <gnumeric.h>
+#include <numbers.h>
+#include <widgets/gnm-expr-entry.h>
 
 typedef struct _scenario_state scenario_state_t;
 
-typedef struct _GenericToolState GenericToolState;
-typedef void (*state_destroy_t) (GenericToolState *state);
+typedef void (*state_destroy_t) (GnmGenericToolState *state);
 
 struct _GenericToolState {
 	GtkBuilder  *gui;
@@ -45,9 +43,9 @@ struct _GenericToolState {
 	state_destroy_t state_destroy;
 } ;
 
-void     tool_load_selection (GenericToolState *state, gboolean allow_multiple);
-void     error_in_entry (GenericToolState *state, GtkWidget *entry, char const *err_str);
-gboolean dialog_tool_init (GenericToolState *state,
+void     tool_load_selection (GnmGenericToolState *state, gboolean allow_multiple);
+void     error_in_entry (GnmGenericToolState *state, GtkWidget *entry, char const *err_str);
+gboolean dialog_tool_init (GnmGenericToolState *state,
 			   WBCGtk *wbcg,
 			   Sheet *sheet,
 			   char const *help_file,
@@ -60,7 +58,7 @@ gboolean dialog_tool_init (GenericToolState *state,
 			   GCallback sensitivity_cb,
 			   GnmExprEntryFlags flags);
 
-GtkWidget *tool_setup_update (GenericToolState* state,
+GtkWidget *tool_setup_update (GnmGenericToolState* state,
 			      char const *name,
 			      GCallback cb,
 			      gpointer closure);
