@@ -1,11 +1,9 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_GUI_UTIL_H_
 # define _GNM_GUI_UTIL_H_
 
-#include "gnumeric-fwd.h"
+#include <gnumeric-fwd.h>
 #include <goffice/goffice.h>
-#include "numbers.h"
-#include <gtk/gtk.h>
+#include <numbers.h>
 
 G_BEGIN_DECLS
 
@@ -61,11 +59,12 @@ typedef void (*GnmPopupMenuHandler) (GnmPopupMenuElement const *e,
 					  gpointer user_data);
 
 void gnm_create_popup_menu (GnmPopupMenuElement const *elements,
-				 GnmPopupMenuHandler handler,
-				 gpointer user_data,
-				 int display_filter,
-				 int sensitive_filter,
-				 GdkEvent *event);
+			    GnmPopupMenuHandler handler,
+			    gpointer user_data,
+			    GDestroyNotify notify,
+			    int display_filter,
+			    int sensitive_filter,
+			    GdkEvent *event);
 
 #define gnm_filter_modifiers(a) ((a) & (GDK_MODIFIER_MASK & (~(GDK_LOCK_MASK|GDK_MOD2_MASK|GDK_MOD5_MASK))))
 
@@ -187,8 +186,11 @@ void gnm_style_context_get_color (GtkStyleContext *context,
 				  GtkStateFlags state,
 				  GdkRGBA *color);
 
-GtkStyleContext * gnm_style_context_from_selector (GtkStyleContext *parent,
-						   const char      *selector);
+void gnm_get_link_color (GtkWidget *widget, GdkRGBA *res);
+gboolean gnm_theme_is_dark (GtkWidget *widget);
+
+void gnm_css_debug_color (const char *name, const GdkRGBA *color);
+void gnm_css_debug_int (const char *name, int i);
 
 G_END_DECLS
 
