@@ -105,6 +105,7 @@ static const GtkStateFlags selection_type_flags[3] = {
 };
 
 static const char * const selection_styles[3] = {
+	// Caution!  assuming a fixed prefix
 	"button.itembar",
 	"button.itembar:hover",
 	"button.itembar:active"
@@ -119,11 +120,20 @@ ib_reload_color_style (GnmItemBar *ib)
 
 	gnm_style_context_get_color (context, GTK_STATE_FLAG_NORMAL,
 				     &ib->grouping_color);
+	gnm_css_debug_color ("item-bar.grouping-color", &ib->grouping_color);
 
 	for (ui = 0; ui < G_N_ELEMENTS (selection_type_flags); ui++) {
 		GtkStateFlags state = selection_type_flags[ui];
 		gnm_style_context_get_color
 			(context, state, &ib->selection_colors[ui]);
+		if (gnm_debug_flag ("css")) {
+			char *name = g_strdup_printf
+				("itembar.%s%s.color",
+				 ib->is_col_header ? "col" : "row",
+				 selection_styles[ui] + strlen (selection_styles[0]));
+			gnm_css_debug_color (name, &ib->selection_colors[ui]);
+			g_free (name);
+		}
 	}
 }
 
@@ -312,6 +322,7 @@ item_bar_realize (GocItem *item)
 					    ? GDK_SB_H_DOUBLE_ARROW
 					    : GDK_SB_V_DOUBLE_ARROW);
 
+	ib_reload_color_style (ib);
 	gnm_item_bar_calc_size (ib);
 }
 
@@ -419,8 +430,6 @@ item_bar_draw_region (GocItem const *item, cairo_t *cr,
 	goc_canvas_c2w (item->canvas, x_0, y_0, &x0, &y0);
 	goc_canvas_c2w (item->canvas, x_1, y_1, &x1, &y1);
 
-	ib_reload_color_style (ib);
-
 	if (ib->is_col_header) {
 		int const inc = gnm_item_bar_group_size (ib, sheet->cols.max_outline_level);
 		int const base_pos = .2 * inc;
