@@ -1184,7 +1184,7 @@ bessel_ij_series_domain (gnm_float x, gnm_float v)
 }
 
 
-static gnm_float
+static GnmQuad
 bessel_ij_series (gnm_float x, gnm_float v, gboolean qj)
 {
 	GnmQuad qv, qxh, qfv, qs, qt;
@@ -1243,7 +1243,7 @@ bessel_ij_series (gnm_float x, gnm_float v, gboolean qj)
 			gnm_quad_add (&qs, &qs, &qt);
 			s = gnm_quad_value (&qs);
 			if (k >= mink &&
-			    gnm_abs (t) <= GNM_EPSILON / 1024 * gnm_abs (s))
+			    gnm_abs (t) <= GNM_EPSILON / (1 << 20) * gnm_abs (s))
 				break;
 		}
 	}
@@ -1253,11 +1253,12 @@ bessel_ij_series (gnm_float x, gnm_float v, gboolean qj)
 
 	// Clamp won't affect whether we get 0 or inf.
 	e = CLAMP (e, G_MININT, G_MAXINT);
-	s = gnm_ldexp (s, (int)e);
+	qs.h = gnm_ldexp (qs.h, (int)e);
+	qs.l = gnm_ldexp (qs.l, (int)e);
 
 	gnm_quad_end (state);
 
-	return s;
+	return qs;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1380,11 +1381,10 @@ static const gnm_float legendre45_wts[(45 + 1) / 2] = {
 	GNM_const(0.0035826631552836)
 };
 
-typedef void (*ComplexIntegrand) (gnm_complex *res, gnm_float x,
-				  const gnm_float *args);
+typedef gnm_complex (*ComplexIntegrand) (gnm_float x, const gnm_float *args);
 
-static void
-complex_legendre_integral (gnm_complex *res, size_t N,
+static gnm_complex
+complex_legendre_integral (size_t N,
 			   gnm_float L, gnm_float H,
 			   ComplexIntegrand f, const gnm_float *args)
 {
@@ -1393,6 +1393,7 @@ complex_legendre_integral (gnm_complex *res, size_t N,
 	gnm_float m = (L + H) / 2;
 	gnm_float s = (H - L) / 2;
 	size_t i;
+	gnm_complex I = GNM_C0;
 
 	switch (N) {
 	case 20:
@@ -1413,23 +1414,19 @@ complex_legendre_integral (gnm_complex *res, size_t N,
 	if (N & 1)
 		g_assert (roots[0] == 0.0);
 
-	gnm_complex_init (res, 0, 0);
 	for (i = 0; i < (N + 1) / 2; i++) {
 		gnm_float r = roots[i];
 		gnm_float w = wts[i];
 		int neg;
 		for (neg = 0; neg <= 1; neg++) {
 			gnm_float u = neg ? m - s * r : m + s * r;
-			gnm_complex dI;
-			f (&dI, u, args);
-			gnm_complex_scale_real (&dI, w);
-			gnm_complex_add (res, res, &dI);
+			gnm_complex dI = f (u, args);
+			I = GNM_CADD (I, GNM_CSCALE (dI, w));
 			if (i == 0 && (N & 1))
 				break;
 		}
 	}
-	res->re *= s;
-	res->im *= s;
+	return GNM_CSCALE (I, s);
 }
 
 // Trapezoid rule integraion for a complex function defined on a finite
@@ -1442,19 +1439,15 @@ complex_trapezoid_integral (gnm_complex *res, size_t N,
 	gnm_float s = (H - L) / N;
 	size_t i;
 
-	gnm_complex_init (res, 0, 0);
+	*res = GNM_C0;
 	for (i = 0; i <= N; i++) {
 		gnm_float u = L + i * s;
-		gnm_complex dI;
-		f (&dI, u, args);
-		if (i == 0 || i == N) {
-			dI.re /= 2;
-			dI.im /= 2;
-		}
-		gnm_complex_add (res, res, &dI);
+		gnm_complex dI = f (u, args);
+		if (i == 0 || i == N)
+			dI = GNM_CSCALE (dI, 0.5);
+		*res = GNM_CADD (*res, dI);
 	}
-	res->re *= s;
-	res->im *= s;
+	*res = GNM_CSCALE (*res, s);
 }
 
 // Shrink integration range to exclude vanishing outer parts.
@@ -1471,8 +1464,8 @@ complex_shink_integral_range (gnm_float *L, gnm_float *H, gnm_float refx,
 	g_return_if_fail (*L <= *H);
 	g_return_if_fail (*L <= refx && refx <= *H);
 
-	f (&y, refx, args);
-	refy = gnm_complex_mod (&y) * GNM_EPSILON;
+	y = f (refx, args);
+	refy = GNM_CABS (y) * GNM_EPSILON;
 
 	g_return_if_fail (!gnm_isnan (refy));
 
@@ -1485,8 +1478,8 @@ complex_shink_integral_range (gnm_float *L, gnm_float *H, gnm_float refx,
 		gnm_float testx = first ? *L : (limL + *L) / 2;
 		gnm_float testy;
 
-		f (&y, testx, args);
-		testy = gnm_complex_mod (&y);
+		y = f (testx, args);
+		testy = GNM_CABS (y);
 
 		first = FALSE;
 		if (testy <= refy) {
@@ -1503,8 +1496,8 @@ complex_shink_integral_range (gnm_float *L, gnm_float *H, gnm_float refx,
 		gnm_float testx = first ? *H : (*H + limH) / 2;
 		gnm_float testy;
 
-		f (&y, testx, args);
-		testy = gnm_complex_mod (&y);
+		y = f (testx, args);
+		testy = GNM_CABS (y);
 
 		first = FALSE;
 		if (testy <= refy) {
@@ -1625,8 +1618,8 @@ debye_u_coeffs (size_t n)
 	return coeffs[n];
 }
 
-static void
-debye_u (gnm_complex *res, size_t n, gnm_float p, gboolean qip)
+static gnm_complex
+debye_u (size_t n, gnm_float p, gboolean qip)
 {
 	const gnm_float *coeffs = debye_u_coeffs (n);
 	gnm_float pn = gnm_pow (p, n);
@@ -1638,18 +1631,10 @@ debye_u (gnm_complex *res, size_t n, gnm_float p, gboolean qip)
 		s = s * pp + coeffs[(i - n) / 2];
 
 	switch (qip ? n % 4 : 0) {
-	case 0:
-		gnm_complex_init (res, s * pn, 0);
-		break;
-	case 1:
-		gnm_complex_init (res, 0, s * pn);
-		break;
-	case 2:
-		gnm_complex_init (res, s * -pn, 0);
-		break;
-	case 3:
-		gnm_complex_init (res, 0, s * -pn);
-		break;
+	case 0: return GNM_CREAL (s * pn);
+	case 1: return GNM_CMAKE (0, s * pn);
+	case 2: return GNM_CREAL (s * -pn);
+	case 3: return GNM_CMAKE (0, s * -pn);
 	default:
 		g_assert_not_reached ();
 	}
@@ -1710,8 +1695,8 @@ gnm_sinhumu (gnm_float u)
 
 /* ------------------------------------------------------------------------ */
 
-static void
-debye_u_sum (gnm_complex *res, gnm_float x, gnm_float nu,
+static gnm_complex
+debye_u_sum (gnm_float x, gnm_float nu,
 	     size_t N, gboolean qalt, gboolean qip)
 {
 	size_t n;
@@ -1719,10 +1704,10 @@ debye_u_sum (gnm_complex *res, gnm_float x, gnm_float nu,
 	gnm_float sqdiff = gnm_abs (x * x - nu * nu);
 	gnm_float diff2 = gnm_sqrt (sqdiff);
 	gnm_float p = nu / diff2;
+	gnm_complex sum = GNM_C0;
 
 	(void)debye_u_coeffs (N);
 
-	gnm_complex_init (res, 0, 0);
 	f = 1;
 	for (n = 0; n <= N; n++) {
 		gnm_complex t;
@@ -1732,17 +1717,19 @@ debye_u_sum (gnm_complex *res, gnm_float x, gnm_float nu,
 			if (qip && (n & 2)) q = -q;
 			if (qalt && (n & 1)) q = -q;
 			if (qip && (n & 1))
-				gnm_complex_init (&t, 0, q);
+				t = GNM_CMAKE (0, q);
 			else
-				gnm_complex_init (&t, q, 0);
+				t = GNM_CREAL (q);
 		} else {
-			debye_u (&t, n, p, qip);
-			gnm_complex_scale_real (&t, f);
+			t = debye_u (n, p, qip);
+			t = GNM_CSCALE (t, f);
 			f /= nu;
 			if (qalt) f = -f;
 		}
-		gnm_complex_add (res, res, &t);
+		sum = GNM_CADD (sum, t);
 	}
+
+	return sum;
 }
 
 static void
@@ -1785,28 +1772,22 @@ debye_29_eta1 (gnm_float x, gnm_float nu,
 	}
 }
 
-static void
-debye_29 (gnm_complex *res, gnm_float x, gnm_float nu, size_t N)
+static gnm_complex
+debye_29 (gnm_float x, gnm_float nu, size_t N)
 {
 	gnm_float sqdiff = x * x - nu * nu;
 	gnm_float eta1a, eta1b, eta1pi;
 	gnm_float f1 = gnm_sqrt (2 / M_PIgnum) / gnm_pow (sqdiff, 0.25);
-	gnm_complex sum, f12, f3;
+	gnm_complex sum, f12;
 
 	debye_29_eta1 (x, nu, &eta1a, &eta1b, &eta1pi);
 
-	gnm_complex_from_polar (&f12, f1, eta1a);
-	if (eta1b) {
-		gnm_complex_from_polar (&f3, 1, eta1b);
-		gnm_complex_mul (&f12, &f12, &f3);
-	}
-	gnm_complex_init (&f3, gnm_cospi (eta1pi), gnm_sinpi (eta1pi));
-	gnm_complex_mul (&f12, &f12, &f3);
-	debye_u_sum (&sum, x, nu, N, TRUE, TRUE);
-	gnm_complex_mul (res, &f12, &sum);
-
-	if (0)
-		g_printerr ("D29(%g,%g) = %.20g + %.20g*i\n", x, nu, res->re, res->im);
+	f12 = GNM_CPOLAR (f1, eta1a);
+	if (eta1b)
+		f12 = GNM_CMUL (f12, GNM_CPOLAR (1, eta1b));
+	f12 = GNM_CMUL (f12, GNM_CPOLARPI (1, eta1pi));
+	sum = debye_u_sum (x, nu, N, TRUE, TRUE);
+	return GNM_CMUL (f12, sum);
 }
 
 static gnm_float
@@ -1818,7 +1799,7 @@ debye_32 (gnm_float x, gnm_float nu, gnm_float eta2, size_t N)
 	gnm_float res;
 	gnm_complex sum;
 
-	debye_u_sum (&sum, x, nu, N, FALSE, FALSE);
+	sum = debye_u_sum (x, nu, N, FALSE, FALSE);
 	res = f * sum.re;
 
 	if (0)
@@ -1831,12 +1812,19 @@ static gnm_float
 debye_33 (gnm_float x, gnm_float nu, gnm_float eta2, size_t N)
 {
 	gnm_float sqdiff = nu * nu - x * x;
-	gnm_float f = - gnm_sqrt (2 / M_PIgnum) * gnm_exp (eta2) /
-		gnm_pow (sqdiff, 0.25);
+	gnm_float f;
 	gnm_float res;
 	gnm_complex sum;
+	gnm_float c = gnm_sqrt (2 / M_PIgnum);
 
-	debye_u_sum (&sum, x, nu, N, TRUE, FALSE);
+	if (eta2 < gnm_log (GNM_MAX) - 0.01)
+		f = - c * gnm_exp (eta2) / gnm_pow (sqdiff, 0.25);
+	else {
+		// Near-overflow panic
+		f = - gnm_exp (gnm_log (c) + eta2 - 0.25 * gnm_log (sqdiff));
+	}
+
+	sum = debye_u_sum (x, nu, N, TRUE, FALSE);
 	res = f * sum.re;
 
 	if (0)
@@ -1909,8 +1897,8 @@ integral_83_cosdiff (gnm_float d, gnm_float v,
 	return s;
 }
 
-static void
-integral_83_integrand (gnm_complex *res, gnm_float v, gnm_float const *args)
+static gnm_complex
+integral_83_integrand (gnm_float v, gnm_float const *args)
 {
 	gnm_float x = args[0];
 	gnm_float nu = args[1];
@@ -1958,28 +1946,24 @@ integral_83_integrand (gnm_complex *res, gnm_float v, gnm_float const *args)
 	xphi1 = x * phi1;
 	if (xphi1 == gnm_ninf) {
 		// "exp" wins.
-		gnm_complex_init (res, 0, 0);
+		return GNM_C0;
 	} else {
 		gnm_float exphi1 = gnm_exp (xphi1);
-		gnm_complex_init (res, du_dv * exphi1, exphi1);
+		return GNM_CMAKE (du_dv * exphi1, exphi1);
 	}
-
-	if (debug)
-		g_printerr ("i83(%g) = %.20g + %.20g*i\n", v, res->re, res->im);
 }
 
-static void
-integral_83_alt_integrand (gnm_complex *res, gnm_float t, gnm_float const *args)
+static gnm_complex
+integral_83_alt_integrand (gnm_float t, gnm_float const *args)
 {
 	// v = t^vpow; dv/dt = vpow*t^(vpow-1)
 	gnm_float vpow = args[3];
-	integral_83_integrand (res, gnm_pow (t, vpow), args);
-	gnm_complex_scale_real (res, vpow * gnm_pow (t, vpow - 1));
+	return GNM_CSCALE (integral_83_integrand (gnm_pow (t, vpow), args),
+			   vpow * gnm_pow (t, vpow - 1));
 }
 
-static void
-integral_83 (gnm_complex *res, gnm_float x, gnm_float nu, size_t N,
-	     gnm_float vpow)
+static gnm_complex
+integral_83 (gnm_float x, gnm_float nu, size_t N, gnm_float vpow)
 {
 	// -i/Pi * exp(i*(x*sin(beta)-nu*beta)) *
 	//    Integrate[(du/dv+i)*exp(x*phi1),{v,0,Pi}]
@@ -1996,7 +1980,7 @@ integral_83 (gnm_complex *res, gnm_float x, gnm_float nu, size_t N,
 
 	// x >= 9 && nu < x - 1.5*crbt(x)
 
-	gnm_complex I, f1, f2;
+	gnm_complex I, f1;
 	gnm_float beta = gnm_acos (nu / x);
 	gnm_float xsinbeta = gnm_sqrt (x * x - nu * nu);
 	gnm_float refx = beta;
@@ -2019,27 +2003,21 @@ integral_83 (gnm_complex *res, gnm_float x, gnm_float nu, size_t N,
 
 	complex_trapezoid_integral (&I, N, L, H, integrand, args);
 
-	gnm_complex_from_polar (&f1, 1, xsinbeta - nu * beta);
-	gnm_complex_init (&f2, 0, -1 / M_PIgnum);
-	gnm_complex_mul (&I, &I, &f1);
-	gnm_complex_mul (res, &I, &f2);
-
-	if (0)
-		g_printerr ("I83(%g,%g) = %.20g + %.20g*i\n",
-			    x, nu, res->re, res->im);
-
+	f1 = GNM_CPOLAR (1, xsinbeta - nu * beta);
+	I = GNM_CMUL (I, f1);
+	return GNM_CMUL (I, GNM_CMAKE (0, -1 / M_PIgnum));
 }
 
-static void
-integral_105_126_integrand (gnm_complex *res, gnm_float u, gnm_float const *args)
+static gnm_complex
+integral_105_126_integrand (gnm_float u, gnm_float const *args)
 {
 	gnm_float x = args[0];
 	gnm_float nu = args[1];
-	gnm_complex_init (res, gnm_exp (x * gnm_sinh (u) - nu * u), 0);
+	return GNM_CREAL (gnm_exp (x * gnm_sinh (u) - nu * u));
 }
 
-static void
-integral_105_126 (gnm_complex *res, gnm_float x, gnm_float nu, gboolean qH0)
+static gnm_complex
+integral_105_126 (gnm_float x, gnm_float nu, gboolean qH0)
 {
 	// -i/Pi * Integrate[Exp[x*Sinh[u]-nu*u],{u,-Infinity,H}]
 	// where H is either 0 or alpha, see below.
@@ -2058,17 +2036,14 @@ integral_105_126 (gnm_complex *res, gnm_float x, gnm_float nu, gboolean qH0)
 	complex_shink_integral_range (&L, &H, refx,
 				      integral_105_126_integrand, args);
 
-	complex_legendre_integral (&I, 45, L, H,
-				   integral_105_126_integrand, args);
+	I = complex_legendre_integral (45, L, H,
+				       integral_105_126_integrand, args);
 
-	gnm_complex_init (res, 0, I.re / -M_PIgnum);
-
-	if (0)
-		g_printerr ("I105(%g,%g) = %.20g * i\n", x, nu, res->im);
+	return GNM_CMAKE (0, I.re / -M_PIgnum);
 }
 
-static void
-integral_106_integrand (gnm_complex *res, gnm_float v, gnm_float const *args)
+static gnm_complex
+integral_106_integrand (gnm_float v, gnm_float const *args)
 {
 	gnm_float x = args[0];
 	gnm_float nu = args[1];
@@ -2086,20 +2061,11 @@ integral_106_integrand (gnm_complex *res, gnm_float v, gnm_float const *args)
 	gnm_float den = x * sinv * sinv * sinhu;
 	gnm_float du_dv = v ? num / den : 0;
 
-	gnm_complex_init (res, exphi3 * du_dv, exphi3);
-
-	if (0) {
-		g_printerr ("u=%g\n", u);
-		g_printerr ("coshalpha=%g\n", coshalpha);
-		g_printerr ("cosh(u)=%g\n", coshu);
-		g_printerr ("sinh(u)=%g\n", sinhu);
-		g_printerr ("xphi3=%g\n", xphi3);
-		g_printerr ("i106(%g) = %.20g + %.20g*i\n", v, res->re, res->im);
-	}
+	return GNM_CMAKE (exphi3 * du_dv, exphi3);
 }
 
-static void
-integral_106 (gnm_complex *res, gnm_float x, gnm_float nu)
+static gnm_complex
+integral_106 (gnm_float x, gnm_float nu)
 {
 	// -i/Pi * Integrate[Exp[x*phi3[v]]*(i+du/dv),{v,0,Pi}]
 	//
@@ -2110,20 +2076,16 @@ integral_106 (gnm_complex *res, gnm_float x, gnm_float nu)
 
 	// Note: 2 < x < nu.
 
-	gnm_complex I, mipi;
+	gnm_complex I;
 	gnm_float L = 0, H = M_PIgnum;
 	gnm_float args[2] = { x, nu };
 
 	complex_shink_integral_range (&L, &H, 0, integral_106_integrand, args);
 
-	complex_legendre_integral (&I, 45, L, H,
-				   integral_106_integrand, args);
+	I = complex_legendre_integral (45, L, H,
+				       integral_106_integrand, args);
 
-	gnm_complex_init (&mipi, 0, -1 / M_PIgnum);
-	gnm_complex_mul (res, &I, &mipi);
-
-	if (0)
-		g_printerr ("I106(%g,%g) = %.20g + %.20g*i\n", x, nu, res->re, res->im);
+	return GNM_CMUL (I, GNM_CMAKE (0, -1 / M_PIgnum));
 }
 
 static gnm_float
@@ -2149,7 +2111,7 @@ integral_127_u (gnm_float v)
 	gnm_float vv, u = 0;
 
 	if (v >= 1)
-		return acosh (v / gnm_sin (v));
+		return gnm_acosh (v / gnm_sin (v));
 
 	// Above formula will suffer from cancellation
 	vv = v * v;
@@ -2158,7 +2120,7 @@ integral_127_u (gnm_float v)
 	u *= v;
 
 	if (0) {
-		gnm_float ref = acosh (v / gnm_sin (v));
+		gnm_float ref = gnm_acosh (v / gnm_sin (v));
 		g_printerr ("XXX: %g %g\n", ref, u);
 	}
 
@@ -2207,8 +2169,8 @@ integral_127_u_m_sinhu_cos_v (gnm_float v, gnm_float u, gnm_float sinhu)
 	return r;
 }
 
-static void
-integral_127_integrand (gnm_complex *res, gnm_float v, gnm_float const *args)
+static gnm_complex
+integral_127_integrand (gnm_float v, gnm_float const *args)
 {
 	gnm_float x = args[0];
 	gnm_float nu = args[1];
@@ -2225,14 +2187,14 @@ integral_127_integrand (gnm_complex *res, gnm_float v, gnm_float const *args)
 
 	gnm_complex xphi4, exphi4, i_du_dv;
 
-	gnm_complex_init (&xphi4, x * -diff + (x - nu) * u, (x - nu) * v);
-	gnm_complex_exp (&exphi4, &xphi4);
-	gnm_complex_init (&i_du_dv, du_dv, 1);
-	gnm_complex_mul (res, &exphi4, &i_du_dv);
+	xphi4 = GNM_CMAKE (x * -diff + (x - nu) * u, (x - nu) * v);
+	exphi4 = GNM_CEXP (xphi4);
+	i_du_dv = GNM_CMAKE (du_dv, 1);
+	return GNM_CMUL (exphi4, i_du_dv);
 }
 
-static void
-integral_127 (gnm_complex *res, gnm_float x, gnm_float nu)
+static gnm_complex
+integral_127 (gnm_float x, gnm_float nu)
 {
 	// -i/Pi * Integrate[Exp[x*phi4[v]]*(i+du/dv),{v,0,Pi}]
 	//
@@ -2241,86 +2203,115 @@ integral_127 (gnm_complex *res, gnm_float x, gnm_float nu)
 	// du/dv = (sin(v)-v*cos(v))/(sin^2(v)*sinh(u(v)))
 	// phi4(v) = sinh(u)*cos(v) - u(v) + tau(u(v) + i * v)
 
-	gnm_complex I, mipi;
+	gnm_complex I;
 	gnm_float L = 0, H = M_PIgnum;
 	gnm_float args[2] = { x, nu };
 
 	complex_shink_integral_range (&L, &H, 0,
 				      integral_127_integrand, args);
 
-	complex_legendre_integral (&I, 33, L, H,
-				   integral_127_integrand, args);
+	I = complex_legendre_integral (33, L, H,
+				       integral_127_integrand, args);
 
-	gnm_complex_init (&mipi, 0, -1 / M_PIgnum);
-	gnm_complex_mul (res, &I, &mipi);
-
-	if (0)
-		g_printerr ("I127(%g,%g) = %.20g + %.20g*i\n", x, nu, res->re, res->im);
+	return GNM_CMUL (I, GNM_CMAKE (0, -1 / M_PIgnum));
 }
 
+static void
+jy_via_j_series (gnm_float x, gnm_float nu, gnm_float *pj, gnm_float *py)
+{
+	void *state = gnm_quad_start ();
+	GnmQuad qnu, qJnu, qJmnu, qYnu, qCos, qSin, qInvSin;
+
+	gnm_quad_init (&qnu, nu);
+	gnm_quad_cospi (&qCos, &qnu);
+	gnm_quad_sinpi (&qSin, &qnu);
+	gnm_quad_div (&qInvSin, &gnm_quad_one, &qSin);
+
+	qJnu = bessel_ij_series (x, nu, TRUE);
+	*pj = gnm_quad_value (&qJnu);
+
+	qJmnu = bessel_ij_series (x, -nu, TRUE);
+
+	gnm_quad_mul (&qYnu, &qJnu, &qCos);
+	gnm_quad_sub (&qYnu, &qYnu, &qJmnu);
+	gnm_quad_mul (&qYnu, &qYnu, &qInvSin);
+
+	*py = gnm_quad_value (&qYnu);
+
+	gnm_quad_end (state);
+}
+
+
 static gnm_float
-y_via_j_series (gnm_float nu, const gnm_float *args)
+cb_y_helper (gnm_float nu, const gnm_float *args)
 {
 	gnm_float x = args[0];
-	gnm_float c = gnm_cospi (nu);
-	gnm_float s = gnm_sinpi (nu);
-	gnm_float c_Jnu = c == 0 ? 0 : c * bessel_ij_series (x, nu, TRUE);
-	gnm_float Jmnu = bessel_ij_series (x, -nu, TRUE);
-	gnm_float Ynu = (c_Jnu - Jmnu) / s;
-	if (0) g_printerr ("via: %.20g %.20g %.20g %.20g %.20g\n", x, nu, c_Jnu, Jmnu, Ynu);
+	gnm_float Ynu;
+	if (nu == gnm_floor (nu)) {
+		g_return_val_if_fail (gnm_abs (nu) < G_MAXINT, gnm_nan);
+		Ynu = gnm_yn ((int)nu, x);
+	} else {
+		gnm_float Jnu;
+		jy_via_j_series (x, nu, &Jnu, &Ynu);
+	}
 	return Ynu;
 }
 
-static void
-hankel1_B1 (gnm_complex *res, gnm_float x, gnm_float nu, size_t N)
+static gnm_complex
+hankel1_B1 (gnm_float x, gnm_float nu, size_t N)
 {
-	debye_29 (res, x, nu, N);
+	return debye_29 (x, nu, N);
 }
 
-static void
-hankel1_B2 (gnm_complex *res, gnm_float x, gnm_float nu, size_t N)
+static gnm_complex
+hankel1_B2 (gnm_float x, gnm_float nu, size_t N)
 {
 	gnm_float q = nu / x;
 	gnm_float d = gnm_sqrt (q * q - 1);
 	gnm_float eta2 = nu * gnm_log (q + d) - gnm_sqrt (nu * nu - x * x);
 
-	res->re = debye_32 (x, nu, eta2, N);
-	res->im = debye_33 (x, nu, eta2, N);
+	return GNM_CMAKE (debye_32 (x, nu, eta2, N),
+			  debye_33 (x, nu, eta2, N));
 }
 
-static void
-hankel1_A1 (gnm_complex *res, gnm_float x, gnm_float nu)
+static gnm_complex
+hankel1_A1 (gnm_float x, gnm_float nu)
 {
-	gnm_float rnu = gnm_floor (nu + 0.5);
-	gnm_float Jnu = bessel_ij_series (x, nu, TRUE);
-	gnm_float Ynu;
+	gnm_float rnu = gnm_floor (nu + 0.49); // Close enough
+	gnm_float Jnu, Ynu;
+	gboolean use_yn = (gnm_abs (rnu) < 100000 - 1);
 
 	if (gnm_abs (nu - rnu) > 5e-4) {
-		gnm_float Jmnu = bessel_ij_series (x, -nu, TRUE);
-		gnm_float c = gnm_cospi (nu);
-		gnm_float s = gnm_sinpi (nu);
-		Ynu = ((c == 0 ? 0 : Jnu * c) - Jmnu) / s;
+		jy_via_j_series (x, nu, &Jnu, &Ynu);
+	} else if (use_yn && nu == rnu) {
+		Jnu = gnm_jn ((int)rnu, x);
+		Ynu = gnm_yn ((int)rnu, x);
 	} else {
+		GnmQuad qJnu = bessel_ij_series (x, nu, TRUE);
 		size_t N = 6;
 		gnm_float dnu = 1e-3;
 		gnm_float args[1] = { x };
-		Ynu = chebyshev_interpolant (N, rnu - dnu, rnu + dnu, nu,
-					     y_via_j_series, args);
+		gnm_float nul = rnu - dnu, nur = rnu + dnu;
+		if (use_yn)
+			N |= 1; // Odd, so we use rnu
+		Ynu = chebyshev_interpolant (N, nul, nur, nu,
+					     cb_y_helper, args);
+
+		Jnu = gnm_quad_value (&qJnu);
 	}
-	gnm_complex_init (res, Jnu, Ynu);
+
+	return GNM_CMAKE (Jnu, Ynu);
 }
 
-static void
-hankel1_A2 (gnm_complex *res, gnm_float x, gnm_float nu)
+static gnm_complex
+hankel1_A2 (gnm_float x, gnm_float nu)
 {
-	gnm_complex I1, I2;
-	integral_105_126 (&I1, x, nu, FALSE);
-	integral_106 (&I2, x, nu);
-	gnm_complex_add (res, &I1, &I2);
+	return GNM_CADD (integral_105_126 (x, nu, FALSE),
+			 integral_106 (x, nu));
 }
 
-static void
-hankel1_A3 (gnm_complex *res, gnm_float x, gnm_float nu, gnm_float g)
+static gnm_complex
+hankel1_A3 (gnm_float x, gnm_float nu, gnm_float g)
 {
 	// Deviation: Matviyenko says to change variable to v = t^4 for g < 5.
 	// That works wonders for BesselJ[9,12.5], but is too sudden for
@@ -2330,27 +2321,25 @@ hankel1_A3 (gnm_complex *res, gnm_float x, gnm_float nu, gnm_float g)
 	// Also, we up the number of points from 37 to 47.
 
 	if (g > 5)
-		integral_83 (res, x, nu, 25, 1);
+		return integral_83 (x, nu, 25, 1);
 	else if (g > 4)
-		integral_83 (res, x, nu, 47, 2);
+		return integral_83 (x, nu, 47, 2);
 	else if (g > 3)
-		integral_83 (res, x, nu, 47, 3);
+		return integral_83 (x, nu, 47, 3);
 	else
-		integral_83 (res, x, nu, 47, 4);
+		return integral_83 (x, nu, 47, 4);
 }
 
-static void
-hankel1_A4 (gnm_complex *res, gnm_float x, gnm_float nu)
+static gnm_complex
+hankel1_A4 (gnm_float x, gnm_float nu)
 {
-	gnm_complex J1, J2;
 	// Deviation: when Matviyenko says that (126) is the same as (105)
 	// with alpha=0, he is glossing over the finer points.  When he should
 	// have said is that the alpha in the limit is replaced by 0 and
 	// that the cosh(alpha) inside is replaced textually by nu/x.  (We may
 	// have nu<x and alpha isn't even defined in that case.)
-	integral_105_126 (&J1, x, nu, TRUE);
-	integral_127 (&J2, x, nu);
-	gnm_complex_add (res, &J1, &J2);
+	return GNM_CADD (integral_105_126 (x, nu, TRUE),
+			 integral_127 (x, nu));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -2361,26 +2350,21 @@ hankel1_A4 (gnm_complex *res, gnm_float x, gnm_float nu)
 // Note: there are a few deviations are fixes in this code.  These are marked
 // with "deviation" or "erratum".
 
-static void
-hankel1 (gnm_complex *res, gnm_float x, gnm_float nu)
+static gnm_complex
+hankel1 (gnm_float x, gnm_float nu)
 {
 	gnm_float cbrtx, g;
 
-	gnm_complex_init (res, gnm_nan, gnm_nan);
 	if (gnm_isnan (x) || gnm_isnan (nu))
-		return;
+		return GNM_CNAN;
 
-	g_return_if_fail (x >= 0);
+	g_return_val_if_fail (x >= 0, GNM_CNAN);
 
 	// Deviation: make this work for negative nu also.
 	if (nu < 0) {
-		gnm_complex Hmnu, r;
-
-		hankel1 (&Hmnu, x, -nu);
+		gnm_complex Hmnu = hankel1 (x, -nu);
 		if (0) g_printerr ("H_{%g,%g} = %.20g + %.20g * i\n", -nu, x, Hmnu.re, Hmnu.im);
-		gnm_complex_init (&r, gnm_cospi (-nu), gnm_sinpi (-nu));
-		gnm_complex_mul (res, &Hmnu, &r);
-		return;
+		return GNM_CMUL (Hmnu, GNM_CPOLARPI (1, -nu));
 	}
 
 	cbrtx = gnm_cbrt (x);
@@ -2399,34 +2383,301 @@ hankel1 (gnm_complex *res, gnm_float x, gnm_float nu)
 			N = 5;
 
 		if (nu < x)
-			hankel1_B1 (res, x, nu, N);
+			return hankel1_B1 (x, nu, N);
 		else
-			hankel1_B2 (res, x, nu, N);
+			return hankel1_B2 (x, nu, N);
 	} else {
 		// Algorithm A
 		// Deviation: we use the series on a wider domain as our
 		// series code uses quad precision.
 		if (bessel_ij_series_domain (x, nu))
-			hankel1_A1 (res, x, nu);
+			return hankel1_A1 (x, nu);
 		else if (nu > x && g > 1.5)
-			hankel1_A2 (res, x, nu);
+			return hankel1_A2 (x, nu);
 		else if (x >= 9 && nu < x && g > 1.5)
-			hankel1_A3 (res, x, nu, g);
+			return hankel1_A3 (x, nu, g);
 		else
-			hankel1_A4 (res, x, nu);
+			return hankel1_A4 (x, nu);
 	}
 }
 
 /* ------------------------------------------------------------------------ */
 
+static gboolean
+bessel_jy_phase_domain (gnm_float x, gnm_float nu)
+{
+	gnm_float anu = gnm_abs (nu);
+	gnm_float ax = gnm_abs (x);
+
+	if (anu < 2)
+		return ax > 1000000;
+
+	if (ax < 20)
+		return anu < ax / 5;
+	if (ax < 30)
+		return anu < ax / 3;
+	if (ax < 50)
+		return anu < ax / 2;
+	if (ax < 100)
+		return anu < ax / 1.5;
+	if (ax < 250)
+		return anu < ax / 1.2;
+
+	return anu < ax / 1.1;
+}
+
+
+static gnm_float
+gnm_bessel_M (gnm_float z, gnm_float nu)
+{
+	gnm_float s = 1;
+	gnm_float tn_z2n = 1;
+	gnm_float z2 = z * z;
+	gnm_float nu2 = nu * nu;
+	int n, NMAX = 400;
+	gboolean debug = FALSE;
+
+	if (debug) g_printerr ("M[%g,%g]\n", nu, z);
+
+	// log2(1.1^400) = 55.00
+
+	for (n = 1; n < NMAX; n++) {
+		gnm_float nmh = n - 0.5;
+		gnm_float f = (nu2 - nmh * nmh) * (nmh / n);
+		gnm_float r = f / z2;
+		if (gnm_abs (r) > 1) {
+			if (debug) g_printerr ("Ratio %g\n", r);
+			break;
+		}
+		tn_z2n *= r;
+		s += tn_z2n;
+		if (debug) g_printerr ("Step %d: %g (%g)\n", n, s, tn_z2n);
+		if (gnm_abs (tn_z2n) < GNM_EPSILON * gnm_abs (s)) {
+			if (debug) g_printerr ("Precision ok\n");
+			break;
+		}
+	}
+
+	return gnm_sqrt (s / (z * (M_PIgnum / 2)));
+}
+
+
+static void
+gnm_quad_reduce_pi (GnmQuad *res, GnmQuad const *a, int p, int *pk)
+{
+	gnm_float k;
+	GnmQuad qk, qa, qb;
+	unsigned ui;
+	static const GnmQuad qh = { 0.5, 0 };
+	static const gnm_float pi_parts[] = {
+		+0x1.921fb54442d18p+1,
+		+0x1.1a62633145c04p-53,
+		+0x1.707344a40938p-104,
+		+0x1.114cf98e80414p-155,
+		+0x1.bea63b139b224p-206,
+		+0x1.14a08798e3404p-258,
+		+0x1.bbdf2a33679a4p-311,
+		+0x1.a431b302b0a6cp-362,
+		+0x1.f25f14374fe1p-414,
+		+0x1.ab6b6a8e122fp-465
+	};
+
+	if (a->h < 0) {
+		GnmQuad ma;
+		ma.h = -a->h;
+		ma.l = -a->l;
+		gnm_quad_reduce_pi (res, &ma, p, pk);
+		res->h = -res->h;
+		res->l = -res->l;
+		*pk = (p >= 0) ? (-*pk) & ((1 << (p + 1)) - 1) : 0;
+		return;
+	}
+
+	if (a->h > gnm_ldexp (1.0, GNM_MANT_DIG))
+		g_warning ("Reduced accuracy for very large trigonometric arguments");
+
+	gnm_quad_div (&qk, a, &gnm_quad_pi);
+	qk.h = gnm_ldexp (qk.h, p);
+	qk.l = gnm_ldexp (qk.l, p);
+
+	gnm_quad_add (&qk, &qk, &qh);
+	gnm_quad_floor (&qk, &qk);
+
+	k = gnm_quad_value (&qk);
+	*pk = (int)(gnm_fmod (k, 1 << (1 + p)));
+
+	k = gnm_ldexp (k, -p);
+	qa = *a;
+	for (ui = 0; ui < G_N_ELEMENTS(pi_parts); ui++) {
+		gnm_quad_mul12 (&qb, pi_parts[ui], k);
+		gnm_quad_sub (&qa, &qa, &qb);
+	}
+
+	*res = qa;
+}
+
+
+static gnm_float
+gnm_bessel_phi (gnm_float z, gnm_float nu, int *n_pi_4)
+{
+	void *state = gnm_quad_start ();
+	GnmQuad qs = gnm_quad_zero;
+	GnmQuad tn_z2n[400], sn_z2n[400];
+	GnmQuad qz, qnu, qzm2, qnu2, nuh, qrz;
+	int n, N, NMAX = 400, j, dk;
+	gnm_float rnu;
+	gnm_float lt = GNM_MAX;
+	gboolean debug = FALSE;
+
+	if (debug) g_printerr ("Phi[%g,%g]\n", nu, z);
+
+	go_quad_init (&qz, z);
+	go_quad_init (&qnu, nu);
+
+	// qzm2 = 1 / (z * z)
+	go_quad_mul12 (&qzm2, z, z);
+	go_quad_div (&qzm2, &gnm_quad_one, &qzm2);
+
+	// qnu2 = nu * nu
+	go_quad_mul12 (&qnu2, nu, nu);
+
+	(void)gnm_frexp (z / nu, &N);
+	N = GNM_MANT_DIG / N + 1;
+	N = MIN (N, (int)G_N_ELEMENTS (tn_z2n));
+
+	tn_z2n[0] = sn_z2n[0] = gnm_quad_one;
+
+	for (n = 1; n < NMAX; n++) {
+		GnmQuad qnmh, qnmh2, qf, qd, qn;
+		gnm_float lt2;
+
+		gnm_quad_init (&qn, n);
+
+		// qnmh = n - 0.5
+		gnm_quad_init (&qnmh, n - 0.5);
+
+		// qnmh2 = (n - 0.5)^2
+		gnm_quad_mul (&qnmh2, &qnmh, &qnmh);
+
+		// qf = (nu^2 - (n - 0.5)^2) * (n - 0.5) / n
+		gnm_quad_sub (&qf, &qnu2, &qnmh2);
+		gnm_quad_mul (&qf, &qf, &qnmh);
+		gnm_quad_div (&qf, &qf, &qn);
+
+		// tn_z2n[n] = tn_z2n[n-1] * f / z^2
+		gnm_quad_mul (&tn_z2n[n], &tn_z2n[n - 1], &qf);
+		gnm_quad_mul (&tn_z2n[n], &tn_z2n[n], &qzm2);
+
+		sn_z2n[n] = gnm_quad_zero;
+		for (j = 1; j <= n; j++) {
+			GnmQuad qp;
+
+			gnm_quad_mul (&qp, &tn_z2n[j], &sn_z2n[n - j]);
+			gnm_quad_sub (&sn_z2n[n], &sn_z2n[n], &qp);
+		}
+
+		gnm_quad_init (&qd, 1 - 2 * n);
+		gnm_quad_div (&qd, &sn_z2n[n], &qd);
+
+		// Break out when the tn ratios go the wrong way.  The
+		// sn ratios can have hickups.
+		lt2 = gnm_abs (gnm_quad_value (&tn_z2n[n]));
+		if (lt2 > lt) {
+			if (debug) g_printerr ("t_n ratio %g\n", lt2 / lt);
+			break;
+		}
+		lt = lt2;
+
+		gnm_quad_add (&qs, &qs, &qd);
+		if (debug) g_printerr ("Step %d: %g (%g)\n", n, gnm_quad_value (&qs), gnm_quad_value (&qd));
+
+		if (gnm_abs (gnm_quad_value (&qd)) < GNM_EPSILON * GNM_EPSILON * gnm_abs (gnm_quad_value (&qs))) {
+			if (debug) g_printerr ("Precision ok\n");
+			break;
+		}
+	}
+	gnm_quad_mul (&qs, &qz, &qs);
+
+	// Add z
+	gnm_quad_reduce_pi (&qrz, &qz, 2, n_pi_4);
+	gnm_quad_add (&qs, &qs, &qrz);
+
+	// Subtract Pi/4
+	(*n_pi_4)--;
+
+	// Subtract nu/2
+	rnu = rint (-2 * nu);
+	*n_pi_4 += (int)fmod (rnu, 8);
+	gnm_quad_init (&nuh, (-2 * nu - rnu) / 4);
+	gnm_quad_mul (&nuh, &nuh, &gnm_quad_pi);
+	gnm_quad_add (&qs, &qs, &nuh);
+
+	gnm_quad_reduce_pi (&qs, &qs, 2, &dk);
+	*n_pi_4 += dk;
+
+	*n_pi_4 &= 7;
+
+	gnm_quad_end (state);
+
+	return gnm_quad_value (&qs);
+}
+
+/* ------------------------------------------------------------------------ */
+
+static gnm_float
+cos_x_plus_n_pi_4 (gnm_float x, int n_pi_4)
+{
+	static const gnm_float SQH = M_SQRT2gnum / 2;
+
+	switch (n_pi_4 & 7) {
+	case 0: return gnm_cos (x);
+	case 1: return (gnm_cos (x) - gnm_sin (x)) * SQH;
+	case 2: return -gnm_sin (x);
+	case 3: return (gnm_cos (x) + gnm_sin (x)) * -SQH;
+	case 4: return -gnm_cos (x);
+	case 5: return (gnm_sin (x) - gnm_cos (x)) * SQH;
+	case 6: return gnm_sin (x);
+	case 7: return (gnm_cos (x) + gnm_sin (x)) * SQH;
+	default: g_assert_not_reached ();
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
+static gnm_float
+gnm_bessel_j_phase (gnm_float x, gnm_float nu)
+{
+	int n_pi_4;
+	gnm_float M = gnm_bessel_M (x, nu);
+	gnm_float phi = gnm_bessel_phi (x, nu, &n_pi_4);
+
+	if (0) g_printerr ("M=%g  phi=%.20g + %d * Pi/4\n", M, phi, n_pi_4);
+
+	return M * cos_x_plus_n_pi_4 (phi, n_pi_4);
+}
+
+static gnm_float
+gnm_bessel_y_phase (gnm_float x, gnm_float nu)
+{
+	int n_pi_4;
+	gnm_float M = gnm_bessel_M (x, nu);
+	gnm_float phi = gnm_bessel_phi (x, nu, &n_pi_4);
+	// Adding 6 means we get sin instead.
+	return M * cos_x_plus_n_pi_4 (phi, n_pi_4 + 6);
+}
+
+/* ------------------------------------------------------------------------ */
+
 gnm_float
 gnm_bessel_i (gnm_float x, gnm_float alpha)
 {
 	if (gnm_isnan (x) || gnm_isnan (alpha))
 		return x + alpha;
 
-	if (bessel_ij_series_domain (x, alpha))
-		return bessel_ij_series (x, alpha, FALSE);
+	if (bessel_ij_series_domain (x, alpha)) {
+		GnmQuad qi = bessel_ij_series (x, alpha, FALSE);
+		return gnm_quad_value (&qi);
+	}
 
 	if (x < 0) {
 		if (alpha != gnm_floor (alpha))
@@ -2452,10 +2703,10 @@ gnm_bessel_j (gnm_float x, gnm_float alpha)
 		return gnm_fmod (alpha, 2) == 0
 			? gnm_bessel_j (-x, alpha)  /* Even for even alpha */
 			: 0 - gnm_bessel_j (-x, alpha);  /* Odd for odd alpha */
+	} else if (bessel_jy_phase_domain (x, alpha)) {
+		return gnm_bessel_j_phase (x, alpha);
 	} else {
-		gnm_complex H1;
-		hankel1 (&H1, x, alpha);
-		return H1.re;
+		return GNM_CRE (hankel1 (x, alpha));
 	}
 }
 
@@ -2478,10 +2729,10 @@ gnm_bessel_y (gnm_float x, gnm_float alpha)
 		return gnm_fmod (alpha, 2) == 0
 			? gnm_bessel_y (-x, alpha)  /* Even for even alpha */
 			: 0 - gnm_bessel_y (-x, alpha);  /* Odd for odd alpha */
+	} else if (bessel_jy_phase_domain (x, alpha)) {
+		return gnm_bessel_y_phase (x, alpha);
 	} else {
-		gnm_complex H1;
-		hankel1 (&H1, x, alpha);
-		return H1.im;
+		return GNM_CIM (hankel1 (x, alpha));
 	}
 }
 
