@@ -1,11 +1,9 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SHEET_CONTROL_GUI_PRIV_H_
 # define _GNM_SHEET_CONTROL_GUI_PRIV_H_
 
-#include "sheet-control-gui.h"
-#include "sheet-control-priv.h"
-#include "sheet-object.h"
-#include <gtk/gtk.h>
+#include <sheet-control-gui.h>
+#include <sheet-control-priv.h>
+#include <sheet-object.h>
 
 G_BEGIN_DECLS
 
@@ -36,6 +34,7 @@ struct _SheetControlGUI {
 	int              vpos, hpos;    /* Handle positions */
 	guint		 pane_drag_handler;
 	int              screen_width, screen_height;
+	guint            scroll_bar_timer;
 
 	/* SheetObject support */
 	GHashTable	 *selected_objects;
@@ -68,7 +67,10 @@ struct _SheetControlGUI {
 		SCGUIMoveFunc	handler;
 	} delayedMovement;
 };
-typedef SheetControlClass SheetControlGUIClass;
+
+typedef struct {
+	SheetControlClass parent_class;
+} SheetControlGUIClass;
 
 /* SCG virtual methods called directly from the GUI layer*/
 void scg_adjust_preferences     (SheetControlGUI *scg);
