@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_SHEET_OBJECT_WIDGET_H_
 # define _GNM_SHEET_OBJECT_WIDGET_H_
 
-#include "sheet-object.h"
+#include <sheet-object.h>
 #include <pango/pango-attributes.h>
 
 G_BEGIN_DECLS
