@@ -9,29 +9,31 @@
 
 #include <gnumeric-config.h>
 #include <glib/gi18n.h>
-#include "gnumeric.h"
+#include <gnumeric.h>
 #include <goffice/goffice.h>
-#include "libgnumeric.h"
-#include "gutils.h"
-#include "command-context.h"
-#include "command-context-stderr.h"
-#include "gnm-plugin.h"
-#include "workbook-view.h"
-#include "workbook.h"
-#include "sheet.h"
-#include "sheet-style.h"
-#include "style-border.h"
-#include "style-color.h"
-#include "cell.h"
-#include "value.h"
-#include "expr.h"
-#include "ranges.h"
-#include "mstyle.h"
-#include "xml-sax.h"
-#include "hlink.h"
-#include "input-msg.h"
-#include "expr-name.h"
-#include "sheet-diff.h"
+#include <libgnumeric.h>
+#include <gutils.h>
+#include <command-context.h>
+#include <command-context-stderr.h>
+#include <gnm-plugin.h>
+#include <workbook-view.h>
+#include <workbook.h>
+#include <sheet.h>
+#include <sheet-style.h>
+#include <style-border.h>
+#include <style-color.h>
+#include <cell.h>
+#include <value.h>
+#include <expr.h>
+#include <ranges.h>
+#include <mstyle.h>
+#include <xml-sax.h>
+#include <hlink.h>
+#include <input-msg.h>
+#include <expr-name.h>
+#include <sheet-diff.h>
+#include <gnumeric-conf.h>
+
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-input.h>
@@ -922,6 +924,8 @@ main (int argc, char const **argv)
 	// No code before here, we need to init threads
 	argv = gnm_pre_parse_init (argc, argv);
 
+	gnm_conf_set_persistence (FALSE);
+
 	ocontext = g_option_context_new (_("OLDFILE NEWFILE"));
 	g_option_context_add_main_entries (ocontext, ssdiff_options, GETTEXT_PACKAGE);
 	g_option_context_add_group	  (ocontext, gnm_get_option_group ());
