@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
  * filter.c:
@@ -35,8 +34,8 @@
 #include <selection.h>
 #include <criteria.h>
 
-#include "filter.h"
-#include "analysis-tools.h"
+#include <tools/filter.h>
+#include <tools/analysis-tools.h>
 
 static void
 filter (data_analysis_output_t *dao, Sheet *sheet, GSList *rows,
