@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 #ifndef __SIMULATION_H__
 #define __SIMULATION_H__
 
-#include "dao.h"
+#include <tools/dao.h>
 
 typedef enum {
 	MedianErr = 1, ModeErr = 2, StddevErr = 4, VarErr = 8, SkewErr = 16,
@@ -46,7 +45,7 @@ typedef struct {
 	GSList   *list_outputs;
 	gchar    **cellnames;
 
-	GTimeVal          start, end;
+	gint64 start, end;
 
 	simstats_t **stats;
 } simulation_t;
