@@ -104,14 +104,13 @@ vcombo_create_list (SheetObject *so,
 
 	g_return_val_if_fail (val != NULL, NULL);
 	g_return_val_if_fail (val->type == GNM_VALIDATION_TYPE_IN_LIST, NULL);
-	g_return_val_if_fail (val->deps[0].texpr != NULL, NULL);
+	g_return_val_if_fail (val->deps[0].base.texpr != NULL, NULL);
 	g_return_val_if_fail (sv != NULL, NULL);
 
 	eval_pos_init_editpos (&ep, sv);
-	v = gnm_expr_top_eval (val->deps[0].texpr, &ep,
-			       GNM_EXPR_EVAL_PERMIT_NON_SCALAR |
-			       GNM_EXPR_EVAL_PERMIT_EMPTY |
-			       GNM_EXPR_EVAL_ARRAY_CONTEXT);
+	v = gnm_expr_top_eval_fake_array (val->deps[0].base.texpr, &ep,
+					  GNM_EXPR_EVAL_PERMIT_NON_SCALAR |
+					  GNM_EXPR_EVAL_PERMIT_EMPTY);
 	if (NULL == v)
 		return NULL;
 
@@ -189,7 +188,7 @@ vcombo_set_bounds (SheetObjectView *sov, double const *coords, gboolean visible)
 		if (h > 20.)	/* clip vertically */
 			h = 20.;
 		h /= scale;
-		goc_item_set (GOC_ITEM (view->children->data),
+		goc_item_set (sheet_object_view_get_item (sov),
 			/* put it outside the cell */
 			"x",	  ((coords[2] >= 0.)? coords[2] / scale: (coords[0] / scale - h + 1.)),
 			"y",	  coords [3] / scale - h + 1.,
