@@ -1,13 +1,15 @@
-#!/usr/bin/python
+#!/usr/bin/python3 -B
 # -----------------------------------------------------------------------------
 
+import GnumericTest
+
 import gi
 gi.require_version('Gnm', '1.12')
 from gi.repository import Gnm
 Gnm.init()
 
 # A context for reporting errors to stderr
-cc = Gnm.CmdContextStderr.new()
+cc = Gnm.CmdContextStderr()
 
 # Load plugins
 Gnm.plugins_init(cc)
